@@ -194,10 +194,10 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
     @XBlock.handler
     def studio_submit(self, request, _suffix):
         self.display_name = request.params["display_name"]
-        self.width = request.params["width"]
-        self.height = request.params["height"]
+        self.width = parse_int(request.params["width"], None)
+        self.height = parse_int(request.params["height"], None)
         self.has_score = request.params["has_score"] == "1"
-        self.weight = request.params["weight"]
+        self.weight = parse_float(request.params["weight"], 1)
         self.fullscreen_on_launch = request.params["fullscreen_on_launch"] == "1"
         self.icon_class = "problem" if self.has_score else "video"
 
@@ -405,16 +405,15 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
                 break
         root = tree.getroot()
 
-        if namespace:
-            resource = root.find("{{{0}}}resources/{{{0}}}resource".format(namespace))
-            schemaversion = root.find(
-                "{{{0}}}metadata/{{{0}}}schemaversion".format(namespace)
-            )
-        else:
-            resource = root.find("resources/resource")
-            schemaversion = root.find("metadata/schemaversion")
+        prefix = "{" + namespace + "}" if namespace else ""
+        resource = root.find(
+            "{prefix}resources/{prefix}resource[@href]".format(prefix=prefix)
+        )
+        schemaversion = root.find(
+            "{prefix}metadata/{prefix}schemaversion".format(prefix=prefix)
+        )
 
-        if resource:
+        if resource is not None:
             self.index_page_path = resource.get("href")
         else:
             self.index_page_path = self.find_relative_file_path("index.html")
@@ -536,5 +535,19 @@ class ScormXBlock(XBlock, CompletableXBlockMixin):
         return settings_service.get_settings_bucket(self)
 
 
+def parse_int(value, default):
+    try:
+        return int(value)
+    except (TypeError, ValueError):
+        return default
+
+
+def parse_float(value, default):
+    try:
+        return float(value)
+    except (TypeError, ValueError):
+        return default
+
+
 class ScormError(Exception):
     pass
